==> lnl-2.1.8.tar.gz: lnl-2.1.8/src/chr_prot.h <==
/* chr.c */
void	init_chr( void );
void	act_chr( chr_t *chr );
bool_t	chk_assist_chr( chr_t *chr );
void	clr_map_chr( chr_t *chr );
void	set_map_chr( chr_t *chr );
void	move_chr( chr_t *chr, move_kind_t kind );
void	move_chr_sub( chr_t *chr, move_kind_t kind );
void	move_chr_std( chr_t *chr );
bool_t	chk_chr_stagger( chr_t *chr );
bool_t	chk_chr_stagger_sub( chr_t *chr, flg_stat_t flg, long rate );
void	move_chr_stagger( chr_t *chr );
bool_t	chk_auto_door( chr_t *chr, long x1, long y1, long x2, long y2 );
bool_t	can_move_chr( chr_t *chr, long x, long y );
void	die_chr( chr_t *p );
void	act_chr_auto_door( chr_t *chr, long x, long y );
void	act_chr_auto_mnstr( chr_t *chr, long x, long y );
bool_t	chr_open_door( chr_t *chr, long dr_n );
bool_t	chr_close_door( chr_t *chr, long dr_n );
bool_t	chr_jam_door( chr_t *chr, long dr_n );
bool_t	chr_disarm_door( chr_t *chr, long dr_n );
void	chr_peep_door( chr_t *chr, long dr_n );
void	chr_srch_door( chr_t *chr, long dr_n );
bool_t	chr_disarm_trap( chr_t *chr, trap_t *trap );
void	chr_srch_trap( chr_t *chr, trap_t *trap );
bool_t	chr_open_item( item_t *item, chr_t *chr );
bool_t	chr_disarm_item( item_t *item, chr_t *chr );
void	chr_srch_item( chr_t *chr, item_t *item );
void	chr_srch_obj( chr_t *chr );
void	move_chr_trgt( chr_t *chr );
bool_t	chk_auto_mark_cont( chr_t *chr );
void	clr_chr_trgt_act( chr_t *chr, bool_t flg_force );
void	clr_chr_trgt( chr_t *chr );
bool_t	set_chr_act(
	chr_t *chr, act_kind_t kind,
	void *p, void *p2,
	long n, long n2
);
void	clr_chr_act( chr_t *chr );
void	lost_trgt( void *p );
void	mark_mbr( chr_t *chr1, mbr_t *mbr2, dist_t dist );
void	mark_mnstr_no_regist( chr_t *chr, mnstr_t *mnstr, dist_t dist );
void	mark_mnstr_dflt( chr_t *chr, mnstr_t *mnstr );
void	mark_mnstr( chr_t *chr, mnstr_t *mnstr, dist_t dist );
void	mark_mnstr_null_no_regist( chr_t *chr, long x, long y, dist_t dist );
void	mark_mnstr_null_dflt( chr_t *chr, long x, long y );
void	mark_mnstr_null( chr_t *chr, long x, long y, dist_t dist );
void	mark_item( chr_t *chr, item_t *item, dist_t dist );
void	mark_door( chr_t *chr, door_t *dr, dist_t dist );
void	mark_trap( chr_t *chr, trap_t *trap, dist_t dist );
void	mark_square( chr_t *chr );
void	mark_pos( chr_t *chr, long x, long y, dist_t dist );
void	stop_zapping( chr_t *chr );
void	chr_srch_begin( chr_t *chr );
void	chr_srch_end( chr_t *chr );
bool_t	chk_infra_vision( chr_t *chr );
bool_t	chr_light_up( chr_t *chr, long x, long y, bool_t flg_on );
void	exp_chr( chr_t *chr, long exp, bool_t flg_draw );
void	set_lev( chr_t *chr, bool_t flg_draw );
char	*get_abl_name( abl_kind_t kind );
long	calc_lev_to_exp( long lev, abl_kind_t abl );
long	calc_need_exp( long lev, abl_kind_t abl );
long	calc_lev_to_val( long lev, abl_kind_t abl );
long	calc_resi( rate_t resi, long n );
long	get_generalist_lev( chr_t *p );
long	get_specialist_lev( chr_t *p );
long	add_hp( chr_t *p, long n );
long	add_mp( chr_t *chr, long n );
long	get_chr_gold( chr_t *chr );
long	add_chr_gold( chr_t *chr, long gold );
square_t	*get_square( chr_t *chr );
void	set_square( chr_t *chr, square_t *sq );
char	*get_trgt_name( trgt_t *trgt );
bool_t	cmp_chr( chr_t *p1, chr_t *p2 );
bool_t	chr_roll(
	chr_t *chr, abl_kind_t abl_main, abl_kind_t abl_sub,
	long difficulty
);

==> lnl-2.1.10.tar.gz: lnl-2.1.10/src/chr_prot.h <==
/* chr.c */
void	init_chr( void );
void	act_chr( chr_t *chr );
bool_t	chk_assist_chr( chr_t *chr );
void	clr_map_chr( chr_t *chr );
void	set_map_chr( chr_t *chr );
void	move_chr( chr_t *chr, move_kind_t kind );
void	move_chr_sub( chr_t *chr, move_kind_t kind );
void	move_chr_std( chr_t *chr );
bool_t	chk_chr_stagger( chr_t *chr );
bool_t	chk_chr_stagger_sub( chr_t *chr, flg_stat_t flg, long rate );
void	move_chr_stagger( chr_t *chr );
bool_t	chk_auto_door( chr_t *chr, long x1, long y1, long x2, long y2 );
bool_t	can_move_chr( chr_t *chr, long x, long y );
void	die_chr( chr_t *p, bool_t flg_add_exp );
void	act_chr_auto_door( chr_t *chr, long x, long y );
void	act_chr_auto_mnstr( chr_t *chr, long x, long y );
bool_t	chr_open_door( chr_t *chr, long dr_n );
bool_t	chr_close_door( chr_t *chr, long dr_n );
bool_t	chr_jam_door( chr_t *chr, long dr_n );
bool_t	chr_disarm_door( chr_t *chr, long dr_n );
void	chr_peep_door( chr_t *chr, long dr_n );
void	chr_srch_door( chr_t *chr, long dr_n );
bool_t	chr_disarm_trap( chr_t *chr, trap_t *trap );
void	chr_srch_trap( chr_t *chr, trap_t *trap );
bool_t	chr_open_item( item_t *item, chr_t *chr );
bool_t	chr_disarm_item( item_t *item, chr_t *chr );
void	chr_srch_item( chr_t *chr, item_t *item );
void	chr_srch_obj( chr_t *chr );
void	move_chr_trgt( chr_t *chr );
bool_t	chk_auto_mark_cont( chr_t *chr );
void	clr_chr_trgt_act( chr_t *chr, bool_t flg_force );
void	clr_chr_trgt( chr_t *chr );
bool_t	set_chr_act(
	chr_t *chr, act_kind_t kind,
	void *p, void *p2,
	long n, long n2
);
void	clr_chr_act( chr_t *chr );
void	lost_trgt( void *p );
void	mark_mbr( chr_t *chr1, mbr_t *mbr2, dist_t dist );
void	mark_mnstr_no_regist( chr_t *chr, mnstr_t *mnstr, dist_t dist );
void	mark_mnstr_dflt( chr_t *chr, mnstr_t *mnstr );
void	mark_mnstr( chr_t *chr, mnstr_t *mnstr, dist_t dist );
void	mark_mnstr_null_no_regist( chr_t *chr, long x, long y, dist_t dist );
void	mark_mnstr_null_dflt( chr_t *chr, long x, long y );
void	mark_mnstr_null( chr_t *chr, long x, long y, dist_t dist );
void	mark_item( chr_t *chr, item_t *item, dist_t dist );
void	mark_door( chr_t *chr, door_t *dr, dist_t dist );
void	mark_trap( chr_t *chr, trap_t *trap, dist_t dist );
void	mark_square( chr_t *chr );
void	mark_pos( chr_t *chr, long x, long y, dist_t dist );
void	stop_zapping( chr_t *chr );
void	chr_srch_begin( chr_t *chr );
void	chr_srch_end( chr_t *chr );
bool_t	chk_infra_vision( chr_t *chr );
bool_t	chr_light_up( chr_t *chr, long x, long y, bool_t flg_on );
void	exp_chr( chr_t *chr, long exp, bool_t flg_draw );
void	set_lev( chr_t *chr, bool_t flg_draw );
char	*get_abl_name( abl_kind_t kind );
long	calc_lev_to_exp( long lev, abl_kind_t abl );
long	calc_need_exp( long lev, abl_kind_t abl );
long	calc_lev_to_val( long lev, abl_kind_t abl );
long	calc_resi( rate_t resi, long n );
long	get_generalist_lev( chr_t *p );
long	get_specialist_lev( chr_t *p );
long	add_hp( chr_t *p, long n );
long	add_mp( chr_t *chr, long n );
long	get_chr_gold( chr_t *chr );
long	add_chr_gold( chr_t *chr, long gold );
square_t	*get_square( chr_t *chr );
void	set_square( chr_t *chr, square_t *sq );
char	*get_trgt_name( trgt_t *trgt );
bool_t	cmp_chr( chr_t *p1, chr_t *p2 );
bool_t	chr_roll(
	chr_t *chr, abl_kind_t abl_main, abl_kind_t abl_sub,
	long difficulty
);
